@@ -1,8 +1,9 @@
 from typing import Optional
 
+from fractal_specifications.generic.specification import Specification
+
 from fractal.core.process.action import Action
 from fractal.core.process.process_scope import ProcessScope
-from fractal.core.specifications.generic.specification import Specification
 
 
 class SetValueAction(Action):
