@@ -24,8 +24,8 @@ def user(account):
 
 
 @pytest.fixture
-def token(dummy_token_service_fractal, user, account):
-    return dummy_token_service_fractal.context.token_service.generate(
+def token(token_roles_service_fractal, user, account):
+    return token_roles_service_fractal.context.token_service.generate(
         {
             "sub": user.id,
             "account": account.id,
@@ -34,8 +34,8 @@ def token(dummy_token_service_fractal, user, account):
 
 
 @pytest.fixture
-def admin_role_token(dummy_token_service_fractal, user, account):
-    return dummy_token_service_fractal.context.token_service.generate(
+def admin_role_token(token_roles_service_fractal, user, account):
+    return token_roles_service_fractal.context.token_service.generate(
         {
             "sub": user.id,
             "account": account.id,
@@ -46,10 +46,15 @@ def admin_role_token(dummy_token_service_fractal, user, account):
 
 @pytest.fixture
 def token_service_application_context(
-    fake_application_context_class, dummy_json_token_service_class
+    fake_application_context_class,
+    dummy_json_token_service_class,
+    dummy_roles_service_class,
 ):
     application_context = fake_application_context_class()
-    application_context.install_service(
+    application_context.token_service = application_context.install_service(
         dummy_json_token_service_class, name="token_service"
-    )
+    )()
+    application_context.roles_service = application_context.install_service(
+        dummy_roles_service_class, name="roles_service"
+    )()
     return application_context
